import { generateSimpleViteManifest, mockConfig, mockFetch, injectApp, mockRedis } from './util.js'
import { expect } from 'chai'
import * as td from 'testdouble'
import RedisMock from 'ioredis-mock'

describe('Redirects', function () {
  let app

  before(async function () {
    await mockConfig({ baseUrls: ['http://ui-server/'] })
    await mockRedis()
    mockFetch({
      'http://ui-server': {
        '/manifest.json': generateSimpleViteManifest({ 'example.js': 'test' }),
        '/example.js': ''
      }
    })
    app = await injectApp()
  })

  afterEach(async function () {
    await new RedisMock().flushdb()
  })

  after(function () {
    td.reset()
  })

  it('without requested location', async function () {
    const response = await app.inject({ method: 'POST', url: '/redirect' })
    expect(response.statusCode).to.equal(302)
    expect(response.headers.location).to.equal('../busy.html')
  })

  it('with requested location', async function () {
    const response = await app.inject({
      method: 'POST',
      url: '/redirect',
      payload: 'location=/appsuite/whatever/path',
      headers: {
        'Content-Type': 'application/x-www-form-urlencoded; charset=UTF-8'
      }
    })
    expect(response.statusCode).to.equal(302)
    expect(response.headers.location).to.equal('/appsuite/whatever/path')
  })

  it('redirects /ui to /', async function () {
    const response = await app.inject({ url: '/ui' })
    expect(response.statusCode).to.equal(302)
    expect(response.headers.location).to.equal('/')
  })
})
