import helmet from '@fastify/helmet'
import fp from 'fastify-plugin'

/**
 * @fastify/helmet enables the use of helmet in a Fastify application.
 *
 * Helmet helps you secure your Fastify apps by setting various HTTP headers.
 * It's not a silver bullet, but it can help!
 *
 * Options can be set in the second parameter of the plugin registration.
 *
 * @see https://github.com/fastify/fastify-helmet
 */

export default fp(async (fastify) => {
  fastify.register(helmet, {
    contentSecurityPolicy: false,
    crossOriginEmbedderPolicy: false,
    originAgentCluster: false,
    crossOriginOpenerPolicy: { policy: 'same-origin-allow-popups' }
  })
})
