import fp from 'fastify-plugin'

// This plugin is used to log requests and responses.
export default fp(async (fastify) => {
  // Logs the request body with the 'trace' level
  fastify.addHook('preHandler', function (req, reply, done) {
    if (req.body) req.log.trace({ body: req.body }, 'parsed body')
    done()
  })

  fastify.addHook('onError', (req, reply, { message, stack, statusCode }, done) => {
    const error = { statusCode, stack }
    reply.log.error(error, message || 'request errored')
    done()
  })

  // Logs the request with the 'debug' level and also logs headers with the 'trace' level
  fastify.addHook('onResponse', (req, reply, done) => {
    const loggingOptions = { url: req.raw.url, res: reply, responseTime: reply.getResponseTime() }
    if (process.env.LOG_LEVEL === 'trace') loggingOptions.headers = req.headers
    reply.log.debug(loggingOptions, 'request completed')
    done()
  })
})
