import fastify from 'fastify'
import promClient from 'prom-client'
import fp from 'fastify-plugin'
import logger from '../logger.js'
import lightship from '../lightship.js'

import fastifyMetrics from 'fastify-metrics'

// This is a metrics server that exposes metrics to Prometheus on the /metrics endpoint on the METRICS_PORT
const app = fastify({ logger: false })
await app.get('/metrics', async (request, reply) => {
  reply
    .type(promClient.register.contentType)
    .send(await promClient.register.metrics())
})
try {
  // Binds and listens for connections on the specified host and port
  await app.listen({ host: '::', port: Number(process.env.METRICS_PORT) })
  logger.info(`Metrics Server listening on port ${process.env.METRICS_PORT}`)
} catch (err) {
  logger.error(err)
  await lightship.shutdown()
}

// This is a graceful shutdown handler for the metrics server
lightship.registerShutdownHandler(async () => {
  await logger.info('Metrics Server Shutting down...')
  if (app) await app.close()
})

// This plugin is used to expose metrics to Prometheus.
export default fp(async (fastify) => {
  await fastify.register(fastifyMetrics, {
    // do not expose metrics endpoint
    endpoint: null
  })
})
