import { configMap } from '../config_map.js'
import * as cache from '../cache.js'
import { getRedisKey } from '../util.js'

async function fetchMergedMetadata () {
  const metadata = await Promise.all(configMap.urls.map(async url => {
    const { origin } = new URL(url)
    try {
      const response = await fetch(new URL('meta.json', origin), { cache: 'no-store' })
      if (!response.ok) return
      return response.json()
    } catch (e) {
      // unhandled
    }
  }))

  metadata.push({
    id: 'ui-middleware',
    name: 'UI Middleware',
    buildDate: process.env.BUILD_TIMESTAMP,
    commitSha: process.env.CI_COMMIT_SHA,
    version: process.env.APP_VERSION
  })

  // only return when contains data
  return metadata.filter(Boolean)
}

export default async function metadataPlugin (fastify) {
  fastify.get('/meta', async (req, res) => {
    const mergedMetadata = await cache.get(getRedisKey({ version: res.version, name: 'mergedMetadata' }), async () => [await fetchMergedMetadata()])
    res.send(mergedMetadata)
  })
}
